NaMaster: nmt_curvedsky_info Struct Reference

NaMaster

- Main Page
- Data Structures
- Files

- Data Structures
- Data Structure Index
- Data Fields

Data Fields
nmt_curvedsky_info Struct Reference

Curved-sky information. More...

`#include <namaster.h>`

## Data Fields
int | is_healpix
| is this HEALPix pixelization? More...
long | n_eq
| equivalent of nside, number of pixels in the equatorial ring More...
int | lmax_sht
| Maximum multipole to compute spherical harmonic transform. More...
int | nx_short
| Number of grid points in the x dimension before completing the circle. More...
int | nx
| Number of grid points in the phi dimension. More...
int | ny
| Number of grid points in the theta dimension. More...
long | npix
| Total number of pixels (given by `nx` * `ny`. More...
flouble | Delta_theta
| pixel size in theta direction More...
flouble | Delta_phi
| pixel size in phi direction More...
flouble | phi0
flouble | theta0

## Detailed Description

Curved-sky information.

This structure contains all the information defining a given full-sky patch. It describes either a HEALPix grid (in which case is_healpix!=0) or a CAR patch (for is_healpix==0). If the latter, then the CAR pixelization must conform to the Clenshaw-Curtis sampling. In this case the colatitude theta must be sampled at N points going from 0 to pi (including both), separated by an interval Dtheta = pi/(N-1). Not all iso-latitude rings must be stored in the patch (i.e. ny!=N necessarily). See the documentation for nmt_curvedsky_info_alloc for further information on the constraints that some of the members of this structure must fulfill.

## Field Documentation

flouble nmt_curvedsky_info::Delta_phi

pixel size in phi direction

flouble nmt_curvedsky_info::Delta_theta

pixel size in theta direction

int nmt_curvedsky_info::is_healpix

is this HEALPix pixelization?

int nmt_curvedsky_info::lmax_sht

Maximum multipole to compute spherical harmonic transform.

long nmt_curvedsky_info::n_eq

equivalent of nside, number of pixels in the equatorial ring

long nmt_curvedsky_info::npix

Total number of pixels (given by `nx` * `ny`.

int nmt_curvedsky_info::nx

Number of grid points in the phi dimension.

int nmt_curvedsky_info::nx_short

Number of grid points in the x dimension before completing the circle.

int nmt_curvedsky_info::ny

Number of grid points in the theta dimension.

flouble nmt_curvedsky_info::phi0

flouble nmt_curvedsky_info::theta0

The documentation for this struct was generated from the following file:

- namaster.h